#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-cabal-plugin-2.3.0.0-IAOq2wTtlPU4AxMDpE96yU
key:                  hls-cabal-plugin-2.3.0.0-IAOq2wTtlPU4AxMDpE96yU
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  046d81a0165ce39261b79e2f252a064d
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Completion.Completer.FilePath
    Ide.Plugin.Cabal.Completion.Completer.Module
    Ide.Plugin.Cabal.Completion.Completer.Paths
    Ide.Plugin.Cabal.Completion.Completer.Simple
    Ide.Plugin.Cabal.Completion.Completer.Snippet
    Ide.Plugin.Cabal.Completion.Completer.Types
    Ide.Plugin.Cabal.Completion.Completions
    Ide.Plugin.Cabal.Completion.Data Ide.Plugin.Cabal.Completion.Types
    Ide.Plugin.Cabal.Diagnostics Ide.Plugin.Cabal.LicenseSuggest
    Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.3.0.0-IAOq2wTtlPU4AxMDpE96yU
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1 directory-1.3.8.5
    extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF filepath-1.4.300.1
    ghcide-2.3.0.0-2s8rQV9irz21pyc5cIsIV0
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hls-graph-2.3.0.0-72RWBHkz19LC8RLM7o3sC0
    hls-plugin-api-2.3.0.0-JWlMOnERUdN8af70lHp5qp
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
    lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4
    regex-tdfa-1.3.2.5-7A9AvRIGkk4HgHOwz4zjio stm-2.5.1.0 text-2.0.2
    text-rope-0.3-Ei55WDCsuAqIC7ggXqwhlE transformers-0.6.1.0
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

